# -*- coding: utf-8 -*-
import pytest
from reportserver.lib.report.esfreport import EsfReport


class TestSQLFactoy(object):
    def test_PWE_esfreport(self):
        report = EsfReport("PWE", [])
        result = report.to_dict()
        assert("po02" in result)
        assert("a2_1" in result)

    def test_SIB_esfreport(self):
        report = EsfReport("SIB", [])
        result = report.to_dict()
        assert("po02" in result)
        assert("a2_1" in result)

    def test_QE_esfreport(self):
        report = EsfReport("QE", [])
        result = report.to_dict()
        assert("c1_1" in result)

    def test_EC_esfreport(self):
        report = EsfReport("EC", [])
        result = report.to_dict()
        assert("c1_2" in result)

    def test_WASKIQ_esfreport(self):
        report = EsfReport("WASKIQ", [])
        result = report.to_dict()
        assert("b3_2" in result)
        assert("po04" in result)

    def test_no_program_esfreport(self):
        report = EsfReport(None, [])
        result = report.to_dict()
        is_in_result = lambda x: x in result
        fields = ["co01", "co02", "co03", "co04", "co05", "co06",
                  "co07", "co08", "co09", "co10", "co11", "co12",
                  "co13", "co14", "co15", "co16", "co17", "co18",
                  "cr01", "cr02", "cr03", "cr04", "cr05", "enters",
                  "exits", "total"]
        expected = [is_in_result(indicator) for indicator in fields]
        assert(all(expected))

    def test_empty_esfreport(self):
        report = EsfReport("WASKIQ", [])
        expected = {'b3_2': {'total': 0, 'male': 0, 'female': 0},
                    'cr05': {'total': 0, 'male': 0, 'female': 0},
                    'cr04': {'total': 0, 'male': 0, 'female': 0},
                    'cr03': {'total': 0, 'male': 0, 'female': 0},
                    'co18': {'total': 0, 'male': 0, 'female': 0},
                    'cr01': {'total': 0, 'male': 0, 'female': 0},
                    'po04': {'total': 0, 'male': 0, 'female': 0},
                    'co15': {'total': 0, 'male': 0, 'female': 0},
                    'co14': {'total': 0, 'male': 0, 'female': 0},
                    'co17': {'total': 0, 'male': 0, 'female': 0},
                    'co16': {'total': 0, 'male': 0, 'female': 0},
                    'co11': {'total': 0, 'male': 0, 'female': 0},
                    'co10': {'total': 0, 'male': 0, 'female': 0},
                    'co13': {'total': 0, 'male': 0, 'female': 0},
                    'co12': {'total': 0, 'male': 0, 'female': 0},
                    'co02': {'total': 0, 'male': 0, 'female': 0},
                    'co03': {'total': 0, 'male': 0, 'female': 0},
                    'co01': {'total': 0, 'male': 0, 'female': 0},
                    'co06': {'total': 0, 'male': 0, 'female': 0},
                    'co07': {'total': 0, 'male': 0, 'female': 0},
                    'co04': {'total': 0, 'male': 0, 'female': 0},
                    'co05': {'total': 0, 'male': 0, 'female': 0},
                    'co08': {'total': 0, 'male': 0, 'female': 0},
                    'co09': {'total': 0, 'male': 0, 'female': 0},
                    'exits': {'total': 0, 'male': 0, 'female': 0},
                    'enters': {'total': 0, 'male': 0, 'female': 0},
                    'cr02': {'total': 0, 'male': 0, 'female': 0},
                    'total': 0,
                    }
        result = report.to_dict()
        assert(expected == result)

    def test_only_male(self):
        rows = [{'b3_2': 1, 'cr05': 1, 'cr04': 1, 'cr03': 1,
                 'co18': 1, 'cr01': 1, 'po04': 1, 'co15': 1,
                 'co14': 1, 'co17': 1, 'co16': 1, 'co11': 1,
                 'co10': 1, 'co13': 1, 'co12': 1, 'enters': 1,
                 'co02': 1, 'co03': 1, 'co01': 1, 'co06': 1,
                 'co07': 1, 'co04': 1, 'co05': 1, 'co08': 1,
                 'co09': 1, 'exits': 1, 'gender': u'male', 'cr02': 1,
                 'total': 25
                 }]
        report = EsfReport("WASKIQ", rows)
        result = report.to_dict()
        expected = {'b3_2': {'total': 1, 'male': 1, 'female': 0},
                    'cr05': {'total': 1, 'male': 1, 'female': 0},
                    'cr04': {'total': 1, 'male': 1, 'female': 0},
                    'cr03': {'total': 1, 'male': 1, 'female': 0},
                    'co18': {'total': 1, 'male': 1, 'female': 0},
                    'cr01': {'total': 1, 'male': 1, 'female': 0},
                    'po04': {'total': 1, 'male': 1, 'female': 0},
                    'co15': {'total': 1, 'male': 1, 'female': 0},
                    'co14': {'total': 1, 'male': 1, 'female': 0},
                    'co17': {'total': 1, 'male': 1, 'female': 0},
                    'co16': {'total': 1, 'male': 1, 'female': 0},
                    'co11': {'total': 1, 'male': 1, 'female': 0},
                    'co10': {'total': 1, 'male': 1, 'female': 0},
                    'co13': {'total': 1, 'male': 1, 'female': 0},
                    'co12': {'total': 1, 'male': 1, 'female': 0},
                    'co02': {'total': 1, 'male': 1, 'female': 0},
                    'co03': {'total': 1, 'male': 1, 'female': 0},
                    'co01': {'total': 1, 'male': 1, 'female': 0},
                    'co06': {'total': 1, 'male': 1, 'female': 0},
                    'co07': {'total': 1, 'male': 1, 'female': 0},
                    'co04': {'total': 1, 'male': 1, 'female': 0},
                    'co05': {'total': 1, 'male': 1, 'female': 0},
                    'co08': {'total': 1, 'male': 1, 'female': 0},
                    'co09': {'total': 1, 'male': 1, 'female': 0},
                    'exits': {'total': 1, 'male': 1, 'female': 0},
                    'enters': {'total': 1, 'male': 1, 'female': 0},
                    'cr02': {'total': 1, 'male': 1, 'female': 0},
                    'total': 25,
                    }
        assert(result == expected)

    def test_only_female(self):
        rows = [{'b3_2': 1, 'cr05': 1, 'cr04': 1, 'cr03': 1,
                 'co18': 1, 'cr01': 1, 'po04': 1, 'co15': 1,
                 'co14': 1, 'co17': 1, 'co16': 1, 'co11': 1,
                 'co10': 1, 'co13': 1, 'co12': 1, 'enters': 1,
                 'co02': 1, 'co03': 1, 'co01': 1, 'co06': 1,
                 'co07': 1, 'co04': 1, 'co05': 1, 'co08': 1,
                 'co09': 1, 'exits': 1, 'gender': u'female', 'cr02': 1,
                 'total': 25
                 }]
        report = EsfReport("WASKIQ", rows)
        result = report.to_dict()
        expected = {'b3_2': {'total': 1, 'male': 0, 'female': 1},
                    'cr05': {'total': 1, 'male': 0, 'female': 1},
                    'cr04': {'total': 1, 'male': 0, 'female': 1},
                    'cr03': {'total': 1, 'male': 0, 'female': 1},
                    'co18': {'total': 1, 'male': 0, 'female': 1},
                    'cr01': {'total': 1, 'male': 0, 'female': 1},
                    'po04': {'total': 1, 'male': 0, 'female': 1},
                    'co15': {'total': 1, 'male': 0, 'female': 1},
                    'co14': {'total': 1, 'male': 0, 'female': 1},
                    'co17': {'total': 1, 'male': 0, 'female': 1},
                    'co16': {'total': 1, 'male': 0, 'female': 1},
                    'co11': {'total': 1, 'male': 0, 'female': 1},
                    'co10': {'total': 1, 'male': 0, 'female': 1},
                    'co13': {'total': 1, 'male': 0, 'female': 1},
                    'co12': {'total': 1, 'male': 0, 'female': 1},
                    'co02': {'total': 1, 'male': 0, 'female': 1},
                    'co03': {'total': 1, 'male': 0, 'female': 1},
                    'co01': {'total': 1, 'male': 0, 'female': 1},
                    'co06': {'total': 1, 'male': 0, 'female': 1},
                    'co07': {'total': 1, 'male': 0, 'female': 1},
                    'co04': {'total': 1, 'male': 0, 'female': 1},
                    'co09': {'total': 1, 'male': 0, 'female': 1},
                    'co05': {'total': 1, 'male': 0, 'female': 1},
                    'co08': {'total': 1, 'male': 0, 'female': 1},
                    'exits': {'total': 1, 'male': 0, 'female': 1},
                    'enters': {'total': 1, 'male': 0, 'female': 1},
                    'cr02': {'total': 1, 'male': 0, 'female': 1},
                    'total': 25,
                    }
        assert(result == expected)

